pub fn list_path(path: &Path, opts: &ListOptions) -> Result<Listing>Expand description
List a single path: if file, return that entry alone; if dir, list children.
With -d / directory, list the path itself even when it is a directory.
pub fn list_path(path: &Path, opts: &ListOptions) -> Result<Listing>List a single path: if file, return that entry alone; if dir, list children.
With -d / directory, list the path itself even when it is a directory.